@@ -7,17 +7,16 @@ use std::{
 fn main() {
     rui(state(
         || "task not started".to_string(),
-        |s| {
-            let txt = s.get();
+        |s, cx| {
             hstack((
-                button(text("press to begin"), move || {
+                button(text("press to begin"), move |_| {
                     spawn(move || {
-                        on_main(move || s.set("task started".into()));
+                        on_main(move |cx| cx[s] = "task started".into());
                         sleep(Duration::from_secs(2));
-                        on_main(move || s.set("task complete".into()));
+                        on_main(move |cx| cx[s] = "task complete".into());
                     });
                 }),
-                text(&txt),
+                text(&cx[s]),
             ))
         },
     ));
