@@ -100,7 +100,8 @@ mod window;
 pub use window::*;
 
 use futures::executor::block_on;
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
+use std::iter::FromIterator;
 
 use vger::color::*;
 use vger::*;
@@ -365,7 +366,7 @@ pub fn rui(view: impl View + 'static) {
 
                 // Process the work queue.
                 while let Some(f) = GLOBAL_WORK_QUEUE.lock().unwrap().pop_front() {
-                    f();
+                    f(&mut cx);
                 }
             }
             tao::event::Event::MainEventsCleared => {
@@ -376,7 +377,7 @@ pub fn rui(view: impl View + 'static) {
                 // You only need to call this if you've determined that you need to redraw, in
                 // applications which do not always need to. Applications that redraw continuously
                 // can just render here instead.
-                if is_state_dirty() {
+                if cx.dirty {
                     // Have the commands changed?
                     let mut new_commands = Vec::new();
                     view.commands(cx.root_id, &mut cx, &mut new_commands);
@@ -395,16 +396,8 @@ pub fn rui(view: impl View + 'static) {
                     // Clean up state.
                     let mut keep = vec![];
                     view.gc(cx.root_id, &mut cx, &mut keep);
-                    {
-                        STATE_MAP.with(|mapcell| {
-                            let mut map = mapcell.borrow_mut();
-                            let mut new_map = StateMap::new();
-                            for id in keep {
-                                new_map.insert(id, map[&id].clone());
-                            }
-                            *map = new_map;
-                        });
-                    }
+                    let keep_set = HashSet::<ViewID>::from_iter(keep);
+                    cx.state_map.retain(|k, _| keep_set.contains(k));
 
                     // Get a new accesskit tree.
                     let mut nodes = vec![];
@@ -425,7 +418,7 @@ pub fn rui(view: impl View + 'static) {
 
                     cx.window.as_ref().unwrap().request_redraw();
 
-                    clear_state_dirty();
+                    cx.dirty = false;
                 }
             }
             tao::event::Event::RedrawRequested(_) => {
@@ -457,10 +450,10 @@ pub fn rui(view: impl View + 'static) {
 
                 // Disable dirtying the state during layout and rendering
                 // to avoid constantly re-rendering if some state is saved.
-                ENABLE_DIRTY.with(|enable| *enable.borrow_mut() = false);
+                cx.enable_dirty = false;
                 view.layout(cx.root_id, [width, height].into(), &mut cx, &mut vger);
                 view.draw(cx.root_id, &mut cx, &mut vger);
-                ENABLE_DIRTY.with(|enable| *enable.borrow_mut() = true);
+                cx.enable_dirty = true;
 
                 let texture_view = frame
                     .texture
@@ -564,54 +557,8 @@ mod tests {
 
     #[test]
     fn test_button() {
-        let _ = button(text("click me"), || {
+        let _ = button(text("click me"), |_cx| {
             println!("clicked!");
         });
     }
-
-    #[test]
-    fn test_state2() {
-        let mut cx = Context::new(None);
-        let v = counter(42);
-        v.print(ViewID::default(), &mut cx);
-    }
-
-    fn counter(start: usize) -> impl View {
-        state(
-            move || start,
-            |count| {
-                let count2 = count;
-                let value_string = format!("value: {:?}", count.get());
-                vstack((
-                    text(value_string.as_str()),
-                    button(text("increment"), move || {
-                        count.with_mut(|value| *value += 1);
-                    }),
-                    button(text("decrement"), move || {
-                        count2.with_mut(|value| *value -= 1);
-                    }),
-                ))
-            },
-        )
-    }
-
-    fn counter3<B>(count: B) -> impl View
-    where
-        B: Binding<usize> + Clone + 'static,
-    {
-        let count2 = count;
-        vstack((
-            button(text("increment"), move || {
-                count.with_mut(|value| *value += 1);
-            }),
-            button(text("decrement"), move || {
-                count2.with_mut(|value| *value -= 1);
-            }),
-        ))
-    }
-
-    #[test]
-    fn test_binding() {
-        let _ = state(|| 42, counter3);
-    }
 }
