@@ -1,44 +1,10 @@
 use {
     crate::*,
-    std::{
-        any::Any,
-        cell::RefCell,
-        collections::VecDeque,
-        rc::Rc,
-        sync::{
-            atomic::{AtomicBool, Ordering},
-            Mutex,
-        },
-    },
+    std::{collections::VecDeque, sync::Mutex},
     tao::event_loop::EventLoopProxy,
 };
 
-pub(crate) type StateMap = HashMap<ViewID, Rc<RefCell<dyn Any>>>;
-
-static STATE_DIRTY: AtomicBool = AtomicBool::new(false);
-
-thread_local! {
-    pub static ENABLE_DIRTY: RefCell<bool> = RefCell::new(true);
-    pub static STATE_MAP: RefCell<StateMap> = RefCell::new(StateMap::new());
-}
-
-pub(crate) fn is_state_dirty() -> bool {
-    STATE_DIRTY.load(Ordering::Relaxed)
-}
-
-pub(crate) fn set_state_dirty() {
-    ENABLE_DIRTY.with(|enable| {
-        if *enable.borrow() {
-            STATE_DIRTY.store(true, Ordering::Relaxed);
-        }
-    })
-}
-
-pub(crate) fn clear_state_dirty() {
-    STATE_DIRTY.store(false, Ordering::Relaxed);
-}
-
-pub(crate) type WorkQueue = VecDeque<Box<dyn FnOnce() + Send>>;
+pub(crate) type WorkQueue = VecDeque<Box<dyn FnOnce(&mut Context) + Send>>;
 
 lazy_static! {
     /// Allows us to wake the event loop whenever we want.
@@ -57,7 +23,7 @@ fn wake_event_loop() {
     }
 }
 
-pub fn on_main(f: impl FnOnce() + Send + 'static) {
+pub fn on_main(f: impl FnOnce(&mut Context) + Send + 'static) {
     GLOBAL_WORK_QUEUE.lock().unwrap().push_back(Box::new(f));
     wake_event_loop();
 }
@@ -65,7 +31,7 @@ pub fn on_main(f: impl FnOnce() + Send + 'static) {
 /// Weak reference to app state.
 #[derive(Clone)]
 pub struct State<S> {
-    id: ViewID,
+    pub(crate) id: ViewID,
     phantom: std::marker::PhantomData<S>,
 }
 
@@ -73,15 +39,9 @@ impl<S> Copy for State<S> where S: Clone {}
 
 impl<S> State<S>
 where
-    S: 'static,
+    S: Clone + 'static,
 {
-    pub fn new(id: ViewID, default: &impl Fn() -> S) -> Self {
-        STATE_MAP.with(|cell| {
-            cell.borrow_mut()
-                .entry(id)
-                .or_insert_with(|| Rc::new(RefCell::new(default())));
-        });
-
+    pub fn new(id: ViewID) -> Self {
         Self {
             id,
             phantom: Default::default(),
@@ -93,27 +53,11 @@ impl<S> Binding<S> for State<S>
 where
     S: Clone + 'static,
 {
-    fn with<T, F: FnOnce(&S) -> T>(&self, f: F) -> T {
-        let s = STATE_MAP.with(|map| map.borrow()[&self.id].clone());
-        let v = s.borrow();
-        if let Some(state) = v.downcast_ref::<S>() {
-            f(state)
-        } else {
-            panic!("state has wrong type")
-        }
+    fn get<'a>(&self, cx: &'a mut Context) -> &'a S {
+        cx.get(*self)
     }
-    fn with_mut<T, F: FnOnce(&mut S) -> T>(&self, f: F) -> T {
-        let s = STATE_MAP.with(|map| map.borrow()[&self.id].clone());
-        set_state_dirty();
-        let t = if let Some(state) = s.borrow_mut().downcast_mut::<S>() {
-            f(state)
-        } else {
-            panic!("state has wrong type")
-        };
-
-        wake_event_loop();
-
-        t
+    fn get_mut<'a>(&self, cx: &'a mut Context) -> &'a mut S {
+        cx.get_mut(*self)
     }
 }
 
@@ -127,22 +71,34 @@ where
     V: View,
     S: Clone + 'static,
     D: Fn() -> S,
-    F: Fn(State<S>) -> V,
+    F: Fn(State<S>, &mut Context) -> V,
 {
     fn print(&self, id: ViewID, cx: &mut Context) {
-        (self.func)(State::new(id, &self.default)).print(id.child(&0), cx);
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).print(id.child(&0), cx);
     }
 
     fn process(&self, event: &Event, id: ViewID, cx: &mut Context, vger: &mut VGER) {
-        (self.func)(State::new(id, &self.default)).process(event, id.child(&0), cx, vger);
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).process(event, id.child(&0), cx, vger);
     }
 
     fn draw(&self, id: ViewID, cx: &mut Context, vger: &mut VGER) {
-        (self.func)(State::new(id, &self.default)).draw(id.child(&0), cx, vger);
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).draw(id.child(&0), cx, vger);
     }
 
     fn layout(&self, id: ViewID, sz: LocalSize, cx: &mut Context, vger: &mut VGER) -> LocalSize {
-        (self.func)(State::new(id, &self.default)).layout(id.child(&0), sz, cx, vger)
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).layout(id.child(&0), sz, cx, vger)
     }
 
     fn hittest(
@@ -152,16 +108,25 @@ where
         cx: &mut Context,
         vger: &mut VGER,
     ) -> Option<ViewID> {
-        (self.func)(State::new(id, &self.default)).hittest(id.child(&0), pt, cx, vger)
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).hittest(id.child(&0), pt, cx, vger)
     }
 
     fn commands(&self, id: ViewID, cx: &mut Context, cmds: &mut Vec<CommandInfo>) {
-        (self.func)(State::new(id, &self.default)).commands(id.child(&0), cx, cmds);
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).commands(id.child(&0), cx, cmds);
     }
 
     fn gc(&self, id: ViewID, cx: &mut Context, map: &mut Vec<ViewID>) {
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
         map.push(id);
-        (self.func)(State::new(id, &self.default)).gc(id.child(&0), cx, map);
+        (self.func)(State::new(id), cx).gc(id.child(&0), cx, map);
     }
 
     fn access(
@@ -170,7 +135,10 @@ where
         cx: &mut Context,
         nodes: &mut Vec<accesskit::Node>,
     ) -> Option<accesskit::NodeId> {
-        (self.func)(State::new(id, &self.default)).access(id.child(&0), cx, nodes)
+        cx.state_map
+            .entry(id)
+            .or_insert_with(|| Box::new((self.default)()));
+        (self.func)(State::new(id), cx).access(id.child(&0), cx, nodes)
     }
 }
 
@@ -178,7 +146,7 @@ impl<S, F> private::Sealed for StateView<S, F> {}
 
 /// State allows you to associate some state with a view.
 /// This is what you'll use for a data model, as well as per-view state.
-/// Your state should be efficiently clonable. Use Arc as necessary.
+/// Your state should be efficiently clonable. Use Rc as necessary.
 ///
 /// `initial` is the initial value for your state.
 ///
@@ -187,7 +155,7 @@ pub fn state<
     S: Clone + 'static,
     V: View + 'static,
     D: Fn() -> S + 'static,
-    F: Fn(State<S>) -> V + 'static,
+    F: Fn(State<S>, &mut Context) -> V + 'static,
 >(
     initial: D,
     f: F,
@@ -196,4 +164,4 @@ pub fn state<
         default: initial,
         func: f,
     }
-}
+}
\ No newline at end of file
