@@ -1,4 +1,4 @@
-pub use crate::*;
+use crate::*;
 
 #[derive(Clone)]
 struct TextEditorState {
@@ -71,35 +71,55 @@ impl TextEditorState {
         }
     }
 
-    fn key(&mut self, k: &KeyPress, text: &impl Binding<String>) {
+    fn key(&mut self, k: &KeyPress, text: String) -> String {
         match k {
-            KeyPress::ArrowLeft => self.back(),
-            KeyPress::ArrowRight => self.fwd(text.with(|t| t.len())),
-            KeyPress::ArrowUp => self.up(),
-            KeyPress::ArrowDown => self.down(),
+            KeyPress::ArrowLeft => {
+                self.back();
+                text
+            }
+            KeyPress::ArrowRight => {
+                self.fwd(text.len());
+                text
+            }
+            KeyPress::ArrowUp => {
+                self.up();
+                text
+            }
+            KeyPress::ArrowDown => {
+                self.down();
+                text
+            }
             KeyPress::Backspace => {
                 if self.cursor > 0 {
-                    text.with_mut(|t| {
-                        t.remove(self.cursor - 1);
-                    });
+                    let mut t = text;
+                    t.remove(self.cursor - 1);
                     self.back();
+                    t
+                } else {
+                    text
                 }
             }
             KeyPress::Character(c) => {
-                text.with_mut(|t| {
-                    t.insert_str(self.cursor, c);
-                });
+                let mut t = text;
+                t.insert_str(self.cursor, c);
                 self.cursor += c.len();
+                t
             }
             KeyPress::Space => {
-                text.with_mut(|t| {
-                    t.insert(self.cursor, ' ');
-                });
+                let mut t = text;
+                t.insert(self.cursor, ' ');
                 self.cursor += 1;
+                t
             }
-            KeyPress::Home => self.cursor = 0,
-            KeyPress::End => self.cursor = text.with(|t| t.len()),
-            _ => (),
+            KeyPress::Home => {
+                self.cursor = 0;
+                text
+            }
+            KeyPress::End => {
+                self.cursor = text.len();
+                text
+            }
+            _ => text,
         }
     }
 }
@@ -116,7 +136,7 @@ impl TextEditorState {
 
 /// Struct for `text_editor`.
 pub struct TextEditor<B> {
-    text: B,
+    text_binding: B,
 }
 
 impl<B> TextEditor<B>
@@ -124,19 +144,19 @@ where
     B: Binding<String>,
 {
     fn body(&self) -> impl View {
-        let text = self.text;
+        let text = self.text_binding;
         focus(move |has_focus| {
-            state(TextEditorState::new, move |state| {
-                let cursor = state.with(|s| s.cursor);
-                canvas(move |rect, vger| {
+            state(TextEditorState::new, move |state, cx| {
+                let cursor = cx[state].cursor;
+                canvas(move |cx, rect, vger| {
                     vger.translate([0.0, rect.height()]);
                     let font_size = 18;
                     let break_width = Some(rect.width());
 
-                    let rects = vger.glyph_positions(&text.get(), font_size, break_width);
-                    let lines = vger.line_metrics(&text.get(), font_size, break_width);
+                    let rects = vger.glyph_positions(text.get(cx), font_size, break_width);
+                    let lines = vger.line_metrics(text.get(cx), font_size, break_width);
 
-                    vger.text(&text.get(), font_size, TEXT_COLOR, break_width);
+                    vger.text(text.get(cx), font_size, TEXT_COLOR, break_width);
 
                     if has_focus {
                         let glyph_rect_paint = vger.color_paint(vger::Color::MAGENTA);
@@ -148,14 +168,14 @@ where
                         );
                     }
 
-                    state.with_mut(|s| {
-                        s.glyph_rects = rects;
-                        s.lines = lines;
-                    });
+                    cx[state].glyph_rects = rects;
+                    cx[state].lines = lines;
                 })
-                .key(move |k| {
+                .key(move |cx, k| {
                     if has_focus {
-                        state.with_mut(|s| s.key(&k, &text))
+                        let t = text.with(cx, |t| t.clone());
+                        let new_t = cx[state].key(&k, t);
+                        text.with_mut(cx, |t| *t = new_t);
                     }
                 })
             })
@@ -173,5 +193,5 @@ where
 impl<B> private::Sealed for TextEditor<B> {}
 
 pub fn text_editor(text: impl Binding<String>) -> impl View {
-    TextEditor { text }
+    TextEditor { text_binding: text }
 }
